@@ -1,7 +1,7 @@
 # flake8: noqa
 from lightwood.encoders.text.helpers.rnn_helpers import *
 from lightwood.encoders.encoder_base import BaseEncoder
-import logging
+from lightwood.logger import log
 import math
 
 
@@ -19,14 +19,14 @@ class RnnEncoder(BaseEncoder):
         self._encoder = None
         self._decoder = None
 
-    def prepare_encoder(self, priming_data):
+    def prepare(self, priming_data):
         if self._prepared:
-            raise Exception('You can only call "prepare_encoder" once for a given encoder.')
+            raise Exception('You can only call "prepare" once for a given encoder.')
 
         no_null_sentences = [x if x is not None else '' for x in priming_data]
         estimated_time = 1/937*self._train_iters*len(no_null_sentences)
         log_every = math.ceil(self._train_iters/100)
-        logging.info('We will train an encoder for this text, on a CPU it will take about {min} minutes'.format(
+        log.info('We will train an encoder for this text, on a CPU it will take about {min} minutes'.format(
             min=estimated_time))
 
         self._input_lang = Lang('input')
@@ -49,7 +49,7 @@ class RnnEncoder(BaseEncoder):
 
     def encode(self, column_data):
         if not self._prepared:
-            raise Exception('You need to call "prepare_encoder" before calling "encode" or "decode".')
+            raise Exception('You need to call "prepare" before calling "encode" or "decode".')
 
         no_null_sentences = [x if x is not None else '' for x in column_data]
         ret = []
@@ -79,7 +79,7 @@ class RnnEncoder(BaseEncoder):
         ret = []
         with torch.no_grad():
             for decoder_hiddens in encoded_values_tensor:
-                decoder_hidden = torch.FloatTensor([[decoder_hiddens.tolist()]])
+                decoder_hidden = torch.FloatTensor([[decoder_hiddens.tolist()]]).to(device)
 
                 decoder_input = torch.tensor([[SOS_token]], device=device)  # SOS
 
